==> framy_generator-0.1.1.tar.gz: test/generators/imports_generator_test.dart <==
import 'package:framy_generator/framy_object.dart';
import 'package:framy_generator/generator/imports_generator.dart';
import 'package:test/test.dart';

void main() {
  group('imports generator result', () {
    test('should import material', () {
      final result = generateImports([]);
      expect(result.contains('import \'package:flutter/material.dart\';\n'),
          isTrue);
    });

    test('should import foundation', () {
      final result = generateImports([]);
      expect(result.contains('import \'package:flutter/foundation.dart\';\n'),
          isTrue);
    });

    test('should contain import from FramyObject', () {
      //given
      final framyObject = FramyObject()..import = 'package:my_app/theme.dart';
      //when
      final result = generateImports([framyObject]);
      //then
      expect(
          result.contains('import \'package:my_app/theme.dart\';\n'), isTrue);
    });

    test(
        'should contain provider import if any widget has a provider dependency',
        () {
      //given
      final framyObject = FramyObject()
        ..type = FramyObjectType.widget
        ..widgetDependencies = [
          FramyWidgetDependency(
            '',
            '',
            '',
            false,
            dependencyType: FramyWidgetDependencyType.provider,
          ),
        ];
      //when
      final result = generateImports([framyObject]);
      //then
      expect(result.contains('import \'package:provider/provider.dart\';\n'),
          isTrue);
    });
  });
}

==> framy_generator-0.1.3.tar.gz: test/generators/imports_generator_test.dart <==
import 'package:framy_generator/framy_object.dart';
import 'package:framy_generator/generator/imports_generator.dart';
import 'package:test/test.dart';

void main() {
  group('imports generator result', () {
    test('should import material', () {
      final result = generateImports([]);
      expect(result.contains('import \'package:flutter/material.dart\';\n'),
          isTrue);
    });

    test('should import foundation', () {
      final result = generateImports([]);
      expect(result.contains('import \'package:flutter/foundation.dart\';\n'),
          isTrue);
    });

    test('should contain import from FramyObject', () {
      //given
      final framyObject = FramyObject()..import = 'package:my_app/theme.dart';
      //when
      final result = generateImports([framyObject]);
      //then
      expect(
          result.contains('import \'package:my_app/theme.dart\';\n'), isTrue);
    });

    test(
        'should contain provider import if any widget has a provider dependency',
        () {
      //given
      final framyObject = FramyObject()
        ..type = FramyObjectType.widget
        ..constructors = [
          FramyObjectConstructor(
            '',
            [
              FramyObjectDependency(
                '',
                '',
                '',
                false,
                dependencyType: FramyDependencyType.provider,
              ),
            ],
          )
        ];
      //when
      final result = generateImports([framyObject]);
      //then
      expect(result.contains('import \'package:provider/provider.dart\';\n'),
          isTrue);
    });
  });
}
